# -*- coding: utf-8 -*- 

from collections import deque

from twisted.internet import defer
from twisted.internet import reactor
from twisted.web.client import Agent, BrowserLikeRedirectAgent
from twisted.web.http_headers import Headers
from twisted.internet.error import ConnectError

class Serialiser():
	def __init__(self):
		self.queue = deque([])
		
	def serialise(self, fn, *args, **kwargs):
		def execute(result, fn, *args, **kwargs):
			return fn(*args,  **kwargs)
		def next(result):
			self.queue.popleft()
			self.callnext()
			return result
		d = defer.Deferred()
		d.addCallback(execute, fn, *args, **kwargs)
		d.addErrback(printError)
		d.addCallback(next)
		self.queue.append(d)
		if len(self.queue) == 1:
			self.callnext()
		return d
		
	def callnext(self):
		if len(self.queue):
			d = self.queue[0]
			d.callback(None)

serialise = Serialiser().serialise

def serialised(fn):

	def inner(self, *args, **kwargs):
		return serialise(fn, self, *args, **kwargs)
	inner.fn = fn
	return inner

def httpRequest(method, url, headers={}):

	agent = BrowserLikeRedirectAgent(Agent(reactor))

	d = agent.request(
		method,
		url.encode('latin-1'),
		Headers(headers)
	)

	return d

def printError(e):
	if e.check(ConnectError):
		print 'Connection error:', e.value
		return
	print '------------------------error.printError: traceback------------------------'
	print e.getTraceback()
	print '---------------------------------------------------------------------------'
