#! /usr/bin/env python
# -*- coding: utf-8 -*-
####################
# Copyright (c) 2012, SSI. All rights reserved.

import os
import sys
import re
from Sonos import Sonos 
import indigoPluginUpdateChecker

class Plugin(indigo.PluginBase):


	######################################################################################
	# class init & del
	def __init__(self, pluginId, pluginDisplayName, pluginVersion, pluginPrefs):
		indigo.PluginBase.__init__(self, pluginId, pluginDisplayName, pluginVersion, pluginPrefs)
		self.Sonos = Sonos(self)	
		self.debug = False
		self.xmlDebug = False
		self.eventsDebug = False
		self.stateUpdatesDebug = False
		self.StopThread = False
		self.updater = indigoPluginUpdateChecker.updateChecker (self, 'http://vulture.lagaros.com/IndigoPlugins/Sonos/versionInfoFile.html')
	
	def __del__(self):
		indigo.PluginBase.__del__(self)


	######################################################################################
	# plugin startup and shutdown
	def startup(self):
		self.debugLog(u"Method: startup")
		self.updater.checkVersionNow()
		self.Sonos.startup()
		
	def shutdown(self):
		self.debugLog(u"Method: shutdown")
		self.Sonos.shutdown()


	######################################################################################
	# ConcurrentThread: Start & Stop
	def runConcurrentThread(self):
		self.debugLog(u"Method: runConcurrentThread")
		self.Sonos.runConcurrentThread()

	def stopConcurrentThread(self):
		self.debugLog(u"Method: stopConcurrentThread")
		self.StopThread = True
		self.Sonos.stopConcurrentThread()

	def deviceStartComm(self, dev):
		self.Sonos.deviceStartComm (dev)

	def deviceStopComm(self, dev):
		self.Sonos.deviceStopComm (dev)

	def checkForUpdates(self):
		indigo.server.log(u"Manually checking for updates")
		self.updater.checkVersionNow()

	def closedPrefsConfigUi(self, valuesDict, userCancelled):
		return self.Sonos.closedPrefsConfigUi(valuesDict, userCancelled)


	######################################################################################
	# Action Menthods

	def actionPlay(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "Play")

	def actionTogglePlay(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "TogglePlay")

	def actionPause(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "Pause")

	def actionStop(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "Stop")

	def actionPrevious(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "Previous")

	def actionNext(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "Next")

	def actionChannelUp(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "ChannelUp")

	def actionChannelDown(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "ChannelDown")

	def actionMuteToggle(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "MuteToggle")

	def actionMuteOn(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "MuteOn")

	def actionMuteOff(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "MuteOff")

	def actionGroupMuteToggle(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "GroupMuteToggle")

	def actionGroupMuteOn(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "GroupMuteOn")

	def actionGroupMuteOff(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "GroupMuteOff")

	def actionVolume(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "Volume")

	def actionVolumeDown(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "VolumeDown")

	def actionVolumeUp(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "VolumeUp")

	def actionGroupVolume(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "GroupVolume")

	def actionRelativeGroupVolume(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "RelativeGroupVolume")

	def actionGroupVolumeDown(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "GroupVolumeDown")

	def actionGroupVolumeUp(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "GroupVolumeUp")

	def actionQ_Crossfade(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "Q_Crossfade")

	def actionQ_Repeat(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "Q_Repeat")

	def actionQ_RepeatOne(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "Q_RepeatOne")

	def actionQ_RepeatToggle(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "Q_RepeatToggle")

	def actionQ_Shuffle(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "Q_Shuffle")

	def actionQ_ShuffleToggle(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "Q_ShuffleToggle")

	def actionQ_Clear(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "Q_Clear")

	def actionQ_Save(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "Q_Save")

	def actionCD_RemovePlaylist(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "CD_RemovePlaylist")

	def actionZP_LIST(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "ZP_LIST")

	def actionZP_LineIn(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "ZP_LineIn")

	def actionZP_Queue(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "ZP_Queue")

	def actionZP_SonosFavorites(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "ZP_SonosFavorites")

	def actionZP_RT_FavStation(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "ZP_RT_FavStation")

	def actionRadioTime(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "RadioTime")

	def actionZP_addPlayerToZone(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "addPlayerToZone")

	def actionZP_setStandalone(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "setStandalone")

	def actionZP_saveStates(self, pluginAction):
		return self.Sonos.actionStates(pluginAction, "saveStates")

	def actionZP_addPlayersToZone(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "addPlayersToZone")

	def actionZP_setStandalones(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "setStandalones")

	def actionZP_announcement(self, pluginAction):
		return self.Sonos.actionAnnouncement(pluginAction, "announcement")

	def actionZP_announcementMP3(self, pluginAction):
		return self.Sonos.actionAnnouncement(pluginAction, "announcementMP3")

	def actionZP_sleepTimer(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "ZP_sleepTimer")

	def actionZP_Pandora(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "ZP_Pandora")

	def actionZP_SiriusXM(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "ZP_SiriusXM")

	def actionZP_TV(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "ZP_TV")

	def actionZP_DumpURI(self, pluginAction):
		return self.Sonos.actionDirect(pluginAction, "ZP_DumpURI")

	def actionPandora_ThumbsUp(self, pluginAction):
		return self.Sonos.actionPandoraThumbs(pluginAction, "thumbs_up")

	def actionPandora_ThumbsDown(self, pluginAction):
		return self.Sonos.actionPandoraThumbs(pluginAction, "thumbs_down")

	######################################################################################
	# Menu Items


	######################################################################################
	# Validations for UI

	def validatePrefsConfigUi(self, valuesDict):
		return self.Sonos.validatePrefsConfigUi(valuesDict)

	######################################################################################
	# Lists for UI

	def getZPDeviceList(self, filter="", valuesDict=None, typeId="", targetId=0):
		return self.Sonos.getZPDeviceList(filter)

	def getZP_LIST(self, filter="", valuesDict=None, typeId="", targetId=0):
		return self.Sonos.getZP_LIST()

	def getZP_LIST_PlaylistObjects(self, filter="", valuesDict=None, typeId="", targetId=0):
		return self.Sonos.getZP_LIST_PlaylistObjects()

	def getZP_LineIn(self, filter="", valuesDict=None, typeId="", targetId=0):
		return self.Sonos.getZP_LineIn()

	def getZP_SonosFavorites(self, filter="", valuesDict=None, typeId="", targetId=0):
		return self.Sonos.getZP_SonosFavorites()

	def getZP_RT_FavStations(self, filter="", valuesDict=None, typeId="", targetId=0):
		return self.Sonos.getZP_RT_FavStations()

	def getZP_Pandora(self, filter="", valuesDict=None, typeId="", targetId=0):
		return self.Sonos.getZP_Pandora()

	def getZP_SiriusXM(self, filter="", valuesDict=None, typeId="", targetId=0):
		return self.Sonos.getZP_SiriusXM()

	def getZP_SoundFiles(self, filter="", valuesDict=None, typeId="", targetId=0):
		return self.Sonos.getZP_SoundFiles()

	def getIVONAVoices(self, filter="", valuesDict=None, typeId="", targetId=0):
		return self.Sonos.getIVONAVoices()

	def getPollyVoices(self, filter="", valuesDict=None, typeId="", targetId=0):
		return self.Sonos.getPollyVoices()

	def getAppleVoices(self, filter="", valuesDict=None, typeId="", targetId=0):
		return self.Sonos.getAppleVoices()

	def getMicrosoftLanguages(self, filter="", valuesDict=None, typeId="", targetId=0):
		return self.Sonos.getMicrosoftLanguages()
